@@ -8,6 +8,8 @@
   \author Satofumi KAMIMURA
 
   $Id$
+
+  \todo skip() ́AɔzuׂH
 */
 
 
@@ -27,6 +29,7 @@ public:
   virtual int recv(char* data, int size, int timeout) = 0;
   virtual int size(void) = 0;
   virtual void clear(void) = 0;
+  virtual void skip(int timeout) = 0;
 };
 
 #endif /* !CONNECTION_INTERFACE_H */
